## Version 0.0.33

This new version includes a significant change in the underlying parsing library, moving from astunparse to astor. This change is expected to improve the performance and reliability of the Llamabot.

### New Features

- The version of Llamabot has been updated from 0.0.32 to 0.0.33 (2e4c61) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- The use of astunparse has been deprecated and replaced with astor for better performance and reliability (326c59) (Eric Ma)
